.. highpymath documentation master file, created by
   sphinx-quickstart on Mon Jun 24 18:43:59 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to highpymath's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   usage/install
   implement/rust
   implement/python



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
